==> apollopay-1.0.1.tar.gz: lib/src/api/entities/payment/refund_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

class Refund extends Entity {
  String? id;
  String? token;
  int amount;
  String currency;
  String? client;
  String? description;
  String? providerReference;
  String? charge;
  DateTime? date;
  String? status;
  Refund({
    this.id,
    this.token,
    required this.amount,
    required this.currency,
    this.client,
    this.description,
    this.providerReference,
    this.charge,
    this.date,
    this.status,
  });

  @override
  Refund copyWith({
    String? id,
    String? token,
    int? amount,
    String? currency,
    String? client,
    String? description,
    String? providerReference,
    String? chargeReference,
    DateTime? date,
    String? status,
  }) {
    return Refund(
      id: id ?? this.id,
      token: token ?? this.token,
      amount: amount ?? this.amount,
      currency: currency ?? this.currency,
      client: client ?? this.client,
      description: description ?? this.description,
      providerReference: providerReference ?? this.providerReference,
      charge: chargeReference ?? this.charge,
      date: date ?? this.date,
      status: status ?? this.status,
    );
  }

  @override
  Map<String, dynamic> toMap({bool databaseFormat = false}) {
    return {
      'token': token,
      'amount': amount,
      'currency': currency,
      if (databaseFormat) 'client': client,
      'description': description,
      'provider_reference': providerReference,
      'charge': charge,
      'date': date?.millisecondsSinceEpoch,
      'status': status,
    };
  }

  factory Refund.fromMap(Map<String, dynamic> map) {
    return Refund(
      id: map['_id'] is ObjectId
          ? map['_id'].toHexString()
          : map['_id'].toString(),
      token: map['token'],
      amount: map['amount']?.toInt() ?? 0,
      currency: map['currency'] ?? '',
      client: map['client'],
      description: map['description'],
      providerReference: map['provider_reference'],
      charge: map['charge'],
      date: map['date'] != null
          ? DateTime.fromMillisecondsSinceEpoch(map['date'])
          : null,
      status: map['status'],
    );
  }

  factory Refund.fromJson(String source) => Refund.fromMap(json.decode(source));

  @override
  String toString() {
    return 'Refund(id: $id, token: $token, amount: $amount, currency: $currency, client: $client, description: $description, providerReference: $providerReference, chargeReference: $charge, date: $date, status: $status)';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is Refund &&
        other.id == id &&
        other.token == token &&
        other.amount == amount &&
        other.currency == currency &&
        other.client == client &&
        other.description == description &&
        other.providerReference == providerReference &&
        other.charge == charge &&
        other.date == date &&
        other.status == status;
  }

  @override
  int get hashCode {
    return id.hashCode ^
        token.hashCode ^
        amount.hashCode ^
        currency.hashCode ^
        client.hashCode ^
        description.hashCode ^
        providerReference.hashCode ^
        charge.hashCode ^
        date.hashCode ^
        status.hashCode;
  }
}

==> apollopay-1.0.4.tar.gz: lib/src/api/entities/payment/refund_entity.dart <==
import 'dart:convert';

import 'package:apollopay/src/api/entities/entity_entity.dart';
import 'package:mongo_dart/mongo_dart.dart';

class Refund extends Entity {
  String? id;
  String? token;
  int amount;
  String currency;
  String? client;
  String? description;
  String? providerReference;
  String? charge;
  DateTime? date;
  String? status;
  Refund({
    this.id,
    this.token,
    required this.amount,
    required this.currency,
    this.client,
    this.description,
    this.providerReference,
    this.charge,
    this.date,
    this.status,
  });

  @override
  Refund copyWith({
    String? id,
    String? token,
    int? amount,
    String? currency,
    String? client,
    String? description,
    String? providerReference,
    String? chargeReference,
    DateTime? date,
    String? status,
  }) {
    return Refund(
      id: id ?? this.id,
      token: token ?? this.token,
      amount: amount ?? this.amount,
      currency: currency ?? this.currency,
      client: client ?? this.client,
      description: description ?? this.description,
      providerReference: providerReference ?? this.providerReference,
      charge: chargeReference ?? charge,
      date: date ?? this.date,
      status: status ?? this.status,
    );
  }

  @override
  Map<String, dynamic> toMap({bool databaseFormat = false}) {
    return {
      'token': token,
      'amount': amount,
      'currency': currency,
      if (databaseFormat) 'client': client,
      'description': description,
      'provider_reference': providerReference,
      'charge': charge,
      'date': date?.millisecondsSinceEpoch,
      'status': status,
    };
  }

  factory Refund.fromMap(Map<String, dynamic> map) {
    return Refund(
      id: map['_id'] is ObjectId
          ? map['_id'].toHexString()
          : map['_id'].toString(),
      token: map['token'],
      amount: map['amount']?.toInt() ?? 0,
      currency: map['currency'] ?? '',
      client: map['client'],
      description: map['description'],
      providerReference: map['provider_reference'],
      charge: map['charge'],
      date: map['date'] != null
          ? DateTime.fromMillisecondsSinceEpoch(map['date'])
          : null,
      status: map['status'],
    );
  }

  factory Refund.fromJson(String source) => Refund.fromMap(json.decode(source));

  @override
  String toString() {
    return 'Refund(id: $id, token: $token, amount: $amount, currency: $currency, client: $client, description: $description, providerReference: $providerReference, chargeReference: $charge, date: $date, status: $status)';
  }

  @override
  bool operator ==(Object? other) {
    if (identical(this, other)) return true;

    return other is Refund &&
        other.id == id &&
        other.token == token &&
        other.amount == amount &&
        other.currency == currency &&
        other.client == client &&
        other.description == description &&
        other.providerReference == providerReference &&
        other.charge == charge &&
        other.date == date &&
        other.status == status;
  }

  @override
  int get hashCode {
    return id.hashCode ^
        token.hashCode ^
        amount.hashCode ^
        currency.hashCode ^
        client.hashCode ^
        description.hashCode ^
        providerReference.hashCode ^
        charge.hashCode ^
        date.hashCode ^
        status.hashCode;
  }
}
